lavalink_rs.model.track API documentation

# lavalink_rs.model.track

class TrackLoadType:

The type of data returned when loading a track.

Track = TrackLoadType.Track
Playlist = TrackLoadType.Playlist
Search = TrackLoadType.Search
Empty = TrackLoadType.Empty
Error = TrackLoadType.Error
class Track:
load_type
data
class TrackData:

Information about a track.

user_data
info
encoded
plugin_info
class TrackInfo:

Information and metadata about the track.

isrc

The track "International Standard Recording Code".

author

The track author.

length

The track length in milliseconds.

identifier

The track identifier.

uri

The track uri.

artwork_url

The track artwork url.

source_name

The track source name.

position

The track starting position in milliseconds.

title

The track title,

is_stream

Whether the track is a stream.

is_seekable

Whether the track is seekable.

class PlaylistData:
plugin_info
info
tracks
class PlaylistInfo:
name

The name of the playlist.

selected_track

The selected track of the playlist.

None if no track is selected.

class TrackError:
severity

The severity of the exception.

message

The message of the exception.

cause

The cause of the exception.